aboutsummaryrefslogtreecommitdiffstats
path: root/src/shared/proparser/qmakeglobals.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/shared/proparser/qmakeglobals.cpp')
-rw-r--r--src/shared/proparser/qmakeglobals.cpp4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/shared/proparser/qmakeglobals.cpp b/src/shared/proparser/qmakeglobals.cpp
index a1d19892b9d..a50fa5437a0 100644
--- a/src/shared/proparser/qmakeglobals.cpp
+++ b/src/shared/proparser/qmakeglobals.cpp
@@ -351,7 +351,7 @@ void QMakeGlobals::parseProperties(const QByteArray &data, QHash<ProKey, ProStri
variant = PropRaw;
else if (name.endsWith(QLatin1String("/get")))
variant = PropGet;
- else // Nothing falls back on /src.
+ else // Nothing falls back on /src or /dev.
continue;
name.chop(4);
} else {
@@ -372,6 +372,8 @@ void QMakeGlobals::parseProperties(const QByteArray &data, QHash<ProKey, ProStri
}
properties.insert(ProKey(name + QLatin1String("/raw")), value);
}
+ if (variant <= PropRaw)
+ properties.insert(ProKey(name + QLatin1String("/dev")), value);
} else if (!name.startsWith(QLatin1String("QT_HOST_"))) {
continue;
}